PEP: 801 Title: Reserved Author: Barry Warsaw \<<barry@python.org>\>
Status: Draft Type: Informational Content-Type: text/x-rst Created:
21-Jun-2018

Abstract
========

This PEP is reserved for future use. Contact the author or [the PEP
editors](peps@python.org) for details.

Copyright
=========

This document has been placed in the public domain.
